@@ -3,6 +3,7 @@ import json
 import logging
 import os
 import sys
+import traceback
 
 import coloredlogs
 import redis
@@ -88,6 +89,20 @@ class Command(ScrapyCommand):
 
         self.spiders = utils.discover_spiders(self.settings)
 
+        self.redis_conn = redis.Redis(
+            host=self.redis_config["host"],
+            port=self.redis_config["port"],
+            password=self.redis_config["password"],
+            db=self.redis_config["db"]
+        )
+
+        self.queue_backlog_name = self.queue_name + '.BACKLOG'
+        self.queue_running_counter_name = self.queue_name + '.COUNTER.RUNNING'
+        self.queue_finished_counter_name = self.queue_name + '.COUNTER.FINISHED'
+
+        self.redis_conn.set(self.queue_running_counter_name, 0)
+        self.redis_conn.set(self.queue_finished_counter_name, 0)
+
     def consumer(self):
         """
         start a single redis consumer worker
@@ -130,15 +145,17 @@ class Command(ScrapyCommand):
                 self.logger.error("unknwon spider {}".format(spider_name))
                 continue
 
-            r.incr(self.queue_name + ".COUNTER.RUNNING", amount=1)
+            r.incr(self.queue_running_counter_name, amount=1)
 
             try:
                 utils.crawl(spider, self.settings, args)
             except Exception as e:
-                self.logger.critical(e)
+                if str(e).strip():
+                    self.logger.critical(
+                        "exception from scrapy {}".format(str(e)))
 
-            r.decr(self.queue_name + ".COUNTER.RUNNING", amount=1)
-            r.incr(self.queue_name + ".COUNTER.FINISHED", amount=1)
+            r.decr(self.queue_running_counter_name, amount=1)
+            r.incr(self.queue_finished_counter_name, amount=1)
 
     def server(self, loop):
         """
@@ -151,12 +168,6 @@ class Command(ScrapyCommand):
 
         app = FastAPI()
         app.x = self
-        app.redis = redis.Redis(
-            host=self.redis_config["host"],
-            port=self.redis_config["port"],
-            password=self.redis_config["password"],
-            db=self.redis_config["db"]
-        )
 
         app.include_router(routes.router)
 
